**Example 1: 服务器绑定CAM角色**



Input: 

```
tccli bm AttachCamRole --cli-unfold-argument  \
    --InstanceId cpm-xxx0 \
    --RoleName camrolename
```

Output: 
```
{
    "Response": {
        "RequestId": "3f02fb0c-f782-4cef-9007-d63c68146e39"
    }
}
```

